@@ -1,4 +1,5 @@
 /* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
+/* exported init enable disable */
 
 const Atk = imports.gi.Atk;
 const DND = imports.ui.dnd;
@@ -15,14 +16,11 @@ const Gtk = imports.gi.Gtk;
 const GLib = imports.gi.GLib;
 const Gio = imports.gi.Gio;
 const Signals = imports.signals;
-const Pango = imports.gi.Pango;
 
 const Gettext = imports.gettext.domain('gnome-shell-extensions');
 const _ = Gettext.gettext;
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 const appSys = Shell.AppSystem.get_default();
 
@@ -43,7 +41,7 @@ class ActivitiesMenuItem extends PopupMenu.PopupBaseMenuItem {
         Main.overview.toggle();
         super.activate(event);
     }
-};
+}
 
 class ApplicationMenuItem extends PopupMenu.PopupBaseMenuItem {
     constructor(button, app) {
@@ -87,7 +85,7 @@ class ApplicationMenuItem extends PopupMenu.PopupBaseMenuItem {
 
     activate(event) {
         this._app.open_new_window(-1);
-        this._button.selectCategory(null, null);
+        this._button.selectCategory(null);
         this._button.menu.toggle();
         super.activate(event);
     }
@@ -113,7 +111,7 @@ class ApplicationMenuItem extends PopupMenu.PopupBaseMenuItem {
     _updateIcon() {
         this._iconBin.set_child(this.getDragActor());
     }
-};
+}
 
 class CategoryMenuItem extends PopupMenu.PopupBaseMenuItem {
     constructor(button, category) {
@@ -135,7 +133,7 @@ class CategoryMenuItem extends PopupMenu.PopupBaseMenuItem {
     }
 
     activate(event) {
-        this._button.selectCategory(this._category, this);
+        this._button.selectCategory(this._category);
         this._button.scrollToCatButton(this);
         super.activate(event);
     }
@@ -192,7 +190,7 @@ class CategoryMenuItem extends PopupMenu.PopupBaseMenuItem {
         // cross-product of AB and AP. See:
         // http://stackoverflow.com/questions/3461453/determine-which-side-of-a-line-a-point-lies
         if (((this.actor.width * y) - (NAVIGATION_REGION_OVERSHOOT * x)) <= 0)
-             return true;
+            return true;
 
         return false;
     }
@@ -222,12 +220,12 @@ class CategoryMenuItem extends PopupMenu.PopupBaseMenuItem {
 
     setActive(active, params) {
         if (active) {
-            this._button.selectCategory(this._category, this);
+            this._button.selectCategory(this._category);
             this._button.scrollToCatButton(this);
         }
         super.setActive(active, params);
     }
-};
+}
 
 class ApplicationsMenu extends PopupMenu.PopupMenu {
     constructor(sourceActor, arrowAlignment, arrowSide, button) {
@@ -256,14 +254,14 @@ class ApplicationsMenu extends PopupMenu.PopupMenu {
 
     toggle() {
         if (this.isOpen) {
-            this._button.selectCategory(null, null);
+            this._button.selectCategory(null);
         } else {
             if (Main.overview.visible)
                 Main.overview.hide();
         }
         super.toggle();
     }
-};
+}
 
 class DesktopTarget {
     constructor() {
@@ -327,8 +325,8 @@ class DesktopTarget {
             (o, res) => {
                 try {
                     o.set_attributes_finish(res);
-                } catch(e) {
-                    log('Failed to update access time: ' + e.message);
+                } catch (e) {
+                    log(`Failed to update access time: ${e.message}`);
                 }
             });
     }
@@ -354,8 +352,8 @@ class DesktopTarget {
                             // Hack: force nautilus to reload file info
                             this._touchFile(file);
                         });
-                } catch(e) {
-                    log('Failed to mark file as trusted: ' + e.message);
+                } catch (e) {
+                    log(`Failed to mark file as trusted: ${e.message}`);
                 }
             });
     }
@@ -368,7 +366,7 @@ class DesktopTarget {
         this._setDesktop(null);
     }
 
-    handleDragOver(source, actor, x, y, time) {
+    handleDragOver(source, _actor, _x, _y, _time) {
         let appInfo = this._getSourceAppInfo(source);
         if (!appInfo)
             return DND.DragMotionResult.CONTINUE;
@@ -376,7 +374,7 @@ class DesktopTarget {
         return DND.DragMotionResult.COPY_DROP;
     }
 
-    acceptDrop(source, actor, x, y, time) {
+    acceptDrop(source, _actor, _x, _y, _time) {
         let appInfo = this._getSourceAppInfo(source);
         if (!appInfo)
             return false;
@@ -392,13 +390,13 @@ class DesktopTarget {
             // copy_async() isn't introspectable :-(
             src.copy(dst, Gio.FileCopyFlags.OVERWRITE, null, null);
             this._markTrusted(dst);
-        } catch(e) {
-            log('Failed to copy to desktop: ' + e.message);
+        } catch (e) {
+            log(`Failed to copy to desktop: ${e.message}`);
         }
 
         return true;
     }
-};
+}
 Signals.addSignalMethods(DesktopTarget.prototype);
 
 let ApplicationsButton = GObject.registerClass(
@@ -522,7 +520,7 @@ class ApplicationsButton extends PanelMenu.Button {
         let [width, height] = area.get_surface_size();
         let stippleColor = themeNode.get_color('-stipple-color');
         let stippleWidth = themeNode.get_length('-stipple-width');
-        let x = Math.floor(width/2) + 0.5;
+        let x = Math.floor(width / 2) + 0.5;
         cr.moveTo(x, 0);
         cr.lineTo(x, height);
         Clutter.cairo_set_source_color(cr, stippleColor);
@@ -532,14 +530,14 @@ class ApplicationsButton extends PanelMenu.Button {
     }
 
     _onOpenStateChanged(menu, open) {
-       if (open) {
-           if (this.reloadFlag) {
-               this._redisplay();
-               this.reloadFlag = false;
-           }
-           this.mainBox.show();
-       }
-       super._onOpenStateChanged(menu, open);
+        if (open) {
+            if (this.reloadFlag) {
+                this._redisplay();
+                this.reloadFlag = false;
+            }
+            this.mainBox.show();
+        }
+        super._onOpenStateChanged(menu, open);
     }
 
     _setKeybinding() {
@@ -564,7 +562,7 @@ class ApplicationsButton extends PanelMenu.Button {
                 let id;
                 try {
                     id = entry.get_desktop_file_id(); // catch non-UTF8 filenames
-                } catch(e) {
+                } catch (e) {
                     continue;
                 }
                 let app = appSys.lookup_app(id);
@@ -650,14 +648,14 @@ class ApplicationsButton extends PanelMenu.Button {
         this.categoriesScrollBox.add_actor(this.categoriesBox);
 
         this.mainBox.add(this.leftBox);
-        this.mainBox.add(this._createVertSeparator(), { expand: false, x_fill: false, y_fill: true});
+        this.mainBox.add(this._createVertSeparator(), { expand: false, x_fill: false, y_fill: true });
         this.mainBox.add(this.applicationsScrollBox, { expand: true, x_fill: true, y_fill: true });
         section.actor.add_actor(this.mainBox);
     }
 
     _display() {
         this._applicationsButtons.clear();
-        this.mainBox.style=('width: 35em;');
+        this.mainBox.style = 'width: 35em;';
         this.mainBox.hide();
 
         //Load categories
@@ -689,11 +687,11 @@ class ApplicationsButton extends PanelMenu.Button {
         let themeContext = St.ThemeContext.get_for_stage(global.stage);
         let scaleFactor = themeContext.scale_factor;
         let categoriesHeight = this.categoriesBox.height / scaleFactor;
-        let height = Math.round(categoriesHeight) + MENU_HEIGHT_OFFSET + 'px';
-        this.mainBox.style+=('height: ' + height);
+        let height = Math.round(categoriesHeight) + MENU_HEIGHT_OFFSET;
+        this.mainBox.style += `height: ${height}px`;
     }
 
-    selectCategory(dir, categoryMenuItem) {
+    selectCategory(dir) {
         this.applicationsBox.get_children().forEach(c => {
             if (c._delegate instanceof PopupMenu.PopupSeparatorMenuItem)
                 c._delegate.destroy();
@@ -708,30 +706,30 @@ class ApplicationsButton extends PanelMenu.Button {
     }
 
     _displayButtons(apps) {
-         if (apps) {
+        if (apps) {
             for (let i = 0; i < apps.length; i++) {
-               let app = apps[i];
-               let item;
-               if (app instanceof Shell.App)
-                   item = this._applicationsButtons.get(app);
-               else
-                   item = new PopupMenu.PopupSeparatorMenuItem();
-               if (!item) {
-                  item = new ApplicationMenuItem(this, app);
-                  item.setDragEnabled(this._desktopTarget.hasDesktop);
-                  this._applicationsButtons.set(app, item);
-               }
-               if (!item.actor.get_parent())
-                  this.applicationsBox.add_actor(item.actor);
+                let app = apps[i];
+                let item;
+                if (app instanceof Shell.App)
+                    item = this._applicationsButtons.get(app);
+                else
+                    item = new PopupMenu.PopupSeparatorMenuItem();
+                if (!item) {
+                    item = new ApplicationMenuItem(this, app);
+                    item.setDragEnabled(this._desktopTarget.hasDesktop);
+                    this._applicationsButtons.set(app, item);
+                }
+                if (!item.actor.get_parent())
+                    this.applicationsBox.add_actor(item.actor);
             }
-         }
+        }
     }
 
-    _listApplications(category_menu_id) {
+    _listApplications(categoryMenuId) {
         let applist;
 
-        if (category_menu_id) {
-            applist = this.applicationsByCategory[category_menu_id];
+        if (categoryMenuId) {
+            applist = this.applicationsByCategory[categoryMenuId];
         } else {
             applist = new Array();
             let favorites = global.settings.get_strv('favorite-apps');
@@ -762,6 +760,6 @@ function disable() {
     activitiesButton.container.show();
 }
 
-function init(metadata) {
-    Convenience.initTranslations();
+function init() {
+    ExtensionUtils.initTranslations();
 }
