@@ -1,17 +1,16 @@
 // -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
 // Start apps on custom workspaces
+/* exported init enable disable */
 
 const Shell = imports.gi.Shell;
 
 const Main = imports.ui.main;
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 class WindowMover {
     constructor() {
-        this._settings = Convenience.getSettings();
+        this._settings = ExtensionUtils.getSettings();
         this._appSystem = Shell.AppSystem.get_default();
         this._appConfigs = new Map();
         this._appData = new Map();
@@ -54,7 +53,7 @@ class WindowMover {
                                               this._appWindowsChanged.bind(this)),
                 moveWindowsId: 0,
                 windows: app.get_windows()
-            }
+            };
             this._appData.set(app, data);
         });
     }
@@ -106,13 +105,13 @@ class WindowMover {
         });
         data.windows = windows;
     }
-};
+}
 
 let prevCheckWorkspaces;
 let winMover;
 
 function init() {
-    Convenience.initTranslations();
+    ExtensionUtils.initTranslations();
 }
 
 function myCheckWorkspaces() {
