@@ -1,5 +1,6 @@
 // -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
 // Start apps on custom workspaces
+/* exported init buildPrefsWidget */
 
 const Gio = imports.gi.Gio;
 const GObject = imports.gi.GObject;
@@ -10,8 +11,6 @@ const _ = Gettext.gettext;
 const N_ = e => e;
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 const SETTINGS_KEY = 'application-list';
 
@@ -32,7 +31,7 @@ const Widget = GObject.registerClass({
         super._init(params);
         this.set_orientation(Gtk.Orientation.VERTICAL);
 
-        this._settings = Convenience.getSettings();
+        this._settings = ExtensionUtils.getSettings();
         this._settings.connect('changed', this._refresh.bind(this));
         this._changedPermitted = false;
 
@@ -40,7 +39,7 @@ const Widget = GObject.registerClass({
         this._store.set_column_types([Gio.AppInfo, GObject.TYPE_STRING, Gio.Icon, GObject.TYPE_INT,
                                       Gtk.Adjustment]);
 
-        let scrolled = new Gtk.ScrolledWindow({ shadow_type: Gtk.ShadowType.IN});
+        let scrolled = new Gtk.ScrolledWindow({ shadow_type: Gtk.ShadowType.IN });
         scrolled.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC);
         this.add(scrolled);
 
@@ -118,8 +117,7 @@ const Widget = GObject.registerClass({
                                     halign: Gtk.Align.END }), 0, 1, 1, 1);
         let adjustment = new Gtk.Adjustment({ lower: 1,
                                               upper: WORKSPACE_MAX,
-                                              step_increment: 1
-                                            });
+                                              step_increment: 1 });
         dialog._spin = new Gtk.SpinButton({ adjustment: adjustment,
                                             snap_to_ticks: true });
         dialog._spin.set_value(1);
@@ -158,7 +156,7 @@ const Widget = GObject.registerClass({
     }
 
     _deleteSelected() {
-        let [any, model, iter] = this._treeView.get_selection().get_selected();
+        let [any, model_, iter] = this._treeView.get_selection().get_selected();
 
         if (any) {
             let appInfo = this._store.get_value(iter, Columns.APPINFO);
@@ -175,7 +173,7 @@ const Widget = GObject.registerClass({
         if (isNaN(index) || index < 0)
             index = 1;
         let path = Gtk.TreePath.new_from_string(pathString);
-        let [model, iter] = this._store.get_iter(path);
+        let [model_, iter] = this._store.get_iter(path);
         let appInfo = this._store.get_value(iter, Columns.APPINFO);
 
         this._changedPermitted = false;
@@ -192,7 +190,7 @@ const Widget = GObject.registerClass({
         this._store.clear();
 
         let currentItems = this._settings.get_strv(SETTINGS_KEY);
-        let validItems = [ ];
+        let validItems = [];
         for (let i = 0; i < currentItems.length; i++) {
             let [id, index] = currentItems[i].split(':');
             let appInfo = Gio.DesktopAppInfo.new(id);
@@ -216,12 +214,12 @@ const Widget = GObject.registerClass({
 
     _checkId(id) {
         let items = this._settings.get_strv(SETTINGS_KEY);
-        return !items.some(i => i.startsWith(id + ':'));
+        return !items.some(i => i.startsWith(`${id}:`));
     }
 
     _appendItem(id, workspace) {
         let currentItems = this._settings.get_strv(SETTINGS_KEY);
-        currentItems.push(id + ':' + workspace);
+        currentItems.push(`${id}:${workspace}`);
         this._settings.set_strv(SETTINGS_KEY, currentItems);
     }
 
@@ -240,16 +238,16 @@ const Widget = GObject.registerClass({
         let index = currentItems.map(el => el.split(':')[0]).indexOf(id);
 
         if (index < 0)
-            currentItems.push(id + ':' + workspace);
+            currentItems.push(`${id}:${workspace}`);
         else
-            currentItems[index] = id + ':' + workspace;
+            currentItems[index] = `${id}:${workspace}`;
         this._settings.set_strv(SETTINGS_KEY, currentItems);
     }
 });
 
 
 function init() {
-    Convenience.initTranslations();
+    ExtensionUtils.initTranslations();
 }
 
 function buildPrefsWidget() {
