@@ -1,5 +1,5 @@
+/* exported init enable disable */
 // Drive menu extension
-const Clutter = imports.gi.Clutter;
 const Gio = imports.gi.Gio;
 const GObject = imports.gi.GObject;
 const St = imports.gi.St;
@@ -9,14 +9,11 @@ const Gettext = imports.gettext.domain('gnome-shell-extensions');
 const _ = Gettext.gettext;
 
 const Main = imports.ui.main;
-const Panel = imports.ui.panel;
 const PanelMenu = imports.ui.panelMenu;
 const PopupMenu = imports.ui.popupMenu;
 const ShellMountOperation = imports.ui.shellMountOperation;
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
     constructor(mount) {
@@ -86,7 +83,7 @@ class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
     _unmountFinish(mount, result) {
         try {
             mount.unmount_with_operation_finish(result);
-        } catch(e) {
+        } catch (e) {
             this._reportFailure(e);
         }
     }
@@ -94,7 +91,7 @@ class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
     _ejectFinish(mount, result) {
         try {
             mount.eject_with_operation_finish(result);
-        } catch(e) {
+        } catch (e) {
             this._reportFailure(e);
         }
     }
@@ -112,7 +109,7 @@ class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
 
         super.activate(event);
     }
-};
+}
 
 let DriveMenu = GObject.registerClass(
 class DriveMenu extends PanelMenu.Button {
@@ -137,7 +134,7 @@ class DriveMenu extends PanelMenu.Button {
             this._updateMenuVisibility();
         });
 
-        this._mounts = [ ];
+        this._mounts = [];
 
         this._monitor.get_mounts().forEach(this._addMount.bind(this));
 
@@ -189,7 +186,7 @@ class DriveMenu extends PanelMenu.Button {
 });
 
 function init() {
-    Convenience.initTranslations();
+    ExtensionUtils.initTranslations();
 }
 
 let _indicator;
