@@ -1,90 +1,79 @@
 // -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
-const Lang = imports.lang;
-
+/* exported enable disable */
 const Workspace = imports.ui.workspace;
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 // testing settings for natural window placement strategy:
-const WINDOW_PLACEMENT_NATURAL_FILLGAPS = true;                     // enlarge windows at the end to fill gaps         // not implemented yet
-const WINDOW_PLACEMENT_NATURAL_GRID_FALLBACK = true;                // fallback to grid mode if all windows have the same size and positions.     // not implemented yet
 const WINDOW_PLACEMENT_NATURAL_ACCURACY = 20;                       // accuracy of window translate moves  (KDE-default: 20)
 const WINDOW_PLACEMENT_NATURAL_GAPS = 5;                            // half of the minimum gap between windows
 const WINDOW_PLACEMENT_NATURAL_MAX_TRANSLATIONS = 5000;             // safety limit for preventing endless loop if something is wrong in the algorithm
 
-const Rect = new Lang.Class({
-    Name: 'NativeWindowPlacement.Rect',
-
-    _init: function(x, y, width, height) {
+class Rect {
+    constructor(x, y, width, height) {
         [this.x, this.y, this.width, this.height] = [x, y, width, height];
-    },
+    }
 
     /**
      * used in _calculateWindowTransformationsNatural to replace Meta.Rectangle that is too slow.
      */
-    copy: function() {
+    copy() {
         return new Rect(this.x, this.y, this.width, this.height);
-    },
+    }
 
-    union: function(rect2) {
+    union(rect2) {
         let dest = this.copy();
-        if (rect2.x < dest.x)
-          {
+        if (rect2.x < dest.x) {
             dest.width += dest.x - rect2.x;
             dest.x = rect2.x;
-          }
-        if (rect2.y < dest.y)
-          {
+        }
+        if (rect2.y < dest.y) {
             dest.height += dest.y - rect2.y;
             dest.y = rect2.y;
-          }
+        }
         if (rect2.x + rect2.width > dest.x + dest.width)
-          dest.width = rect2.x + rect2.width - dest.x;
+            dest.width = rect2.x + rect2.width - dest.x;
         if (rect2.y + rect2.height > dest.y + dest.height)
-          dest.height = rect2.y + rect2.height - dest.y;
+            dest.height = rect2.y + rect2.height - dest.y;
 
         return dest;
-    },
+    }
 
-    adjusted: function(dx, dy, dx2, dy2) {
+    adjusted(dx, dy, dx2, dy2) {
         let dest = this.copy();
         dest.x += dx;
         dest.y += dy;
         dest.width += -dx + dx2;
         dest.height += -dy + dy2;
         return dest;
-    },
+    }
 
-    overlap: function(rect2) {
+    overlap(rect2) {
         return !((this.x + this.width    <= rect2.x) ||
                  (rect2.x + rect2.width  <= this.x) ||
                  (this.y + this.height   <= rect2.y) ||
                  (rect2.y + rect2.height <= this.y));
-    },
+    }
 
-    center: function() {
+    center() {
         return [this.x + this.width / 2, this.y + this.height / 2];
-    },
+    }
 
-    translate: function(dx, dy) {
+    translate(dx, dy) {
         this.x += dx;
         this.y += dy;
     }
-});
+}
 
-const NaturalLayoutStrategy = new Lang.Class({
-    Name: 'NaturalLayoutStrategy',
-    Extends: Workspace.LayoutStrategy,
-
-    _init: function(settings) {
+class NaturalLayoutStrategy extends Workspace.LayoutStrategy {
+    constructor(settings) {
+        super();
         this._settings = settings;
-    },
+    }
 
-    computeLayout: function(windows, layout) {
+    computeLayout(windows, layout) {
         layout.windows = windows;
-    },
+    }
 
     /**
      * Returns clones with matching target coordinates and scales to arrange windows in a natural way that no overlap exists and relative window size is preserved.
@@ -92,12 +81,12 @@ const NaturalLayoutStrategy = new Lang.Class({
      * PresentWindowsEffect::calculateWindowTransformationsNatural() from KDE, see:
      * https://projects.kde.org/projects/kde/kdebase/kde-workspace/repository/revisions/master/entry/kwin/effects/presentwindows/presentwindows.cpp
      */
-    computeWindowSlots: function(layout, area) {
+    computeWindowSlots(layout, area) {
         // As we are using pseudo-random movement (See "slot") we need to make sure the list
         // is always sorted the same way no matter which window is currently active.
 
-        let area_rect = new Rect(area.x, area.y, area.width, area.height);
-        let bounds = area_rect.copy();
+        let areaRect = new Rect(area.x, area.y, area.width, area.height);
+        let bounds = areaRect.copy();
         let clones = layout.windows;
 
         let direction = 0;
@@ -117,31 +106,31 @@ const NaturalLayoutStrategy = new Lang.Class({
             }
         }
 
-        let loop_counter = 0;
+        let loopCounter = 0;
         let overlap;
         do {
             overlap = false;
             for (let i = 0; i < rects.length; i++) {
                 for (let j = 0; j < rects.length; j++) {
                     if (i != j && rects[i].adjusted(-WINDOW_PLACEMENT_NATURAL_GAPS, -WINDOW_PLACEMENT_NATURAL_GAPS,
-                                                    WINDOW_PLACEMENT_NATURAL_GAPS, WINDOW_PLACEMENT_NATURAL_GAPS).overlap(
-                                                     rects[j].adjusted(-WINDOW_PLACEMENT_NATURAL_GAPS, -WINDOW_PLACEMENT_NATURAL_GAPS,
-                                                                       WINDOW_PLACEMENT_NATURAL_GAPS, WINDOW_PLACEMENT_NATURAL_GAPS))) {
-                        loop_counter++;
+                                                    WINDOW_PLACEMENT_NATURAL_GAPS, WINDOW_PLACEMENT_NATURAL_GAPS)
+                                          .overlap(rects[j].adjusted(-WINDOW_PLACEMENT_NATURAL_GAPS, -WINDOW_PLACEMENT_NATURAL_GAPS,
+                                                                     WINDOW_PLACEMENT_NATURAL_GAPS, WINDOW_PLACEMENT_NATURAL_GAPS))) {
+                        loopCounter++;
                         overlap = true;
 
                         // TODO: something like a Point2D would be nicer here:
 
                         // Determine pushing direction
-                        let i_center = rects[i].center();
-                        let j_center = rects[j].center();
-                        let diff = [j_center[0] - i_center[0], j_center[1] - i_center[1]];
+                        let iCenter = rects[i].center();
+                        let jCenter = rects[j].center();
+                        let diff = [jCenter[0] - iCenter[0], jCenter[1] - iCenter[1]];
 
                         // Prevent dividing by zero and non-movement
                         if (diff[0] == 0 && diff[1] == 0)
                             diff[0] = 1;
                         // Try to keep screen/workspace aspect ratio
-                        if ( bounds.height / bounds.width > area_rect.height / area_rect.width )
+                        if ( bounds.height / bounds.width > areaRect.height / areaRect.width )
                             diff[0] *= 2;
                         else
                             diff[1] *= 2;
@@ -170,7 +159,7 @@ const NaturalLayoutStrategy = new Lang.Class({
                             let xSection = Math.round((rects[i].x - bounds.x) / (bounds.width / 3));
                             let ySection = Math.round((rects[i].y - bounds.y) / (bounds.height / 3));
 
-                            let i_center = rects[i].center();
+                            let iCenter = rects[i].center();
                             diff[0] = 0;
                             diff[1] = 0;
                             if (xSection != 1 || ySection != 1) { // Remove this if you want the center to pull as well
@@ -180,23 +169,23 @@ const NaturalLayoutStrategy = new Lang.Class({
                                     ySection = (directions[i] % 2 ? 2 : 0);
                             }
                             if (xSection == 0 && ySection == 0) {
-                                diff[0] = bounds.x - i_center[0];
-                                diff[1] = bounds.y - i_center[1];
+                                diff[0] = bounds.x - iCenter[0];
+                                diff[1] = bounds.y - iCenter[1];
                             }
                             if (xSection == 2 && ySection == 0) {
-                                diff[0] = bounds.x + bounds.width - i_center[0];
-                                diff[1] = bounds.y - i_center[1];
+                                diff[0] = bounds.x + bounds.width - iCenter[0];
+                                diff[1] = bounds.y - iCenter[1];
                             }
                             if (xSection == 2 && ySection == 2) {
-                                diff[0] = bounds.x + bounds.width - i_center[0];
-                                diff[1] = bounds.y + bounds.height - i_center[1];
+                                diff[0] = bounds.x + bounds.width - iCenter[0];
+                                diff[1] = bounds.y + bounds.height - iCenter[1];
                             }
                             if (xSection == 0 && ySection == 2) {
-                                diff[0] = bounds.x - i_center[0];
-                                diff[1] = bounds.y + bounds.height - i_center[1];
+                                diff[0] = bounds.x - iCenter[0];
+                                diff[1] = bounds.y + bounds.height - iCenter[1];
                             }
                             if (diff[0] != 0 || diff[1] != 0) {
-                                let length = Math.sqrt(diff[0]*diff[0] + diff[1]*diff[1]);
+                                let length = Math.sqrt(diff[0] * diff[0] + diff[1] * diff[1]);
                                 diff[0] *= WINDOW_PLACEMENT_NATURAL_ACCURACY / length / 2;   // /2 to make it less influencing than the normal center-move above
                                 diff[1] *= WINDOW_PLACEMENT_NATURAL_ACCURACY / length / 2;
                                 rects[i].translate(diff[0], diff[1]);
@@ -209,44 +198,37 @@ const NaturalLayoutStrategy = new Lang.Class({
                     }
                 }
             }
-        } while (overlap && loop_counter < WINDOW_PLACEMENT_NATURAL_MAX_TRANSLATIONS);
+        } while (overlap && loopCounter < WINDOW_PLACEMENT_NATURAL_MAX_TRANSLATIONS);
 
         // Work out scaling by getting the most top-left and most bottom-right window coords.
         let scale;
-        scale = Math.min(area_rect.width / bounds.width,
-                         area_rect.height / bounds.height,
+        scale = Math.min(areaRect.width / bounds.width,
+                         areaRect.height / bounds.height,
                          1.0);
 
         // Make bounding rect fill the screen size for later steps
-        bounds.x = bounds.x - (area_rect.width - bounds.width * scale) / 2;
-        bounds.y = bounds.y - (area_rect.height - bounds.height * scale) / 2;
-        bounds.width = area_rect.width / scale;
-        bounds.height = area_rect.height / scale;
+        bounds.x = bounds.x - (areaRect.width - bounds.width * scale) / 2;
+        bounds.y = bounds.y - (areaRect.height - bounds.height * scale) / 2;
+        bounds.width = areaRect.width / scale;
+        bounds.height = areaRect.height / scale;
 
         // Move all windows back onto the screen and set their scale
         for (let i = 0; i < rects.length; i++) {
             rects[i].translate(-bounds.x, -bounds.y);
         }
 
-        // TODO: Implement the KDE part "Try to fill the gaps by enlarging windows if they have the space" here. (If this is wanted)
-
         // rescale to workspace
-        let scales = [];
-
-        let buttonOuterHeight, captionHeight;
-        let buttonOuterWidth = 0;
-
         let slots = [];
         for (let i = 0; i < rects.length; i++) {
-            rects[i].x = rects[i].x * scale + area_rect.x;
-            rects[i].y = rects[i].y * scale + area_rect.y;
+            rects[i].x = rects[i].x * scale + areaRect.x;
+            rects[i].y = rects[i].y * scale + areaRect.y;
 
             slots.push([rects[i].x, rects[i].y, scale, clones[i]]);
         }
 
         return slots;
     }
-});
+}
 
 let winInjections, workspaceInjections;
 
@@ -258,7 +240,7 @@ function resetState() {
 function enable() {
     resetState();
 
-    let settings = Convenience.getSettings();
+    let settings = ExtensionUtils.getSettings();
 
     workspaceInjections['_getBestLayout'] = Workspace.Workspace.prototype._getBestLayout;
     Workspace.Workspace.prototype._getBestLayout = function(windows) {
@@ -267,7 +249,7 @@ function enable() {
         strategy.computeLayout(windows, layout);
 
         return layout;
-    }
+    };
 
     /// position window titles on top of windows in overlay ////
     winInjections['relayout'] = Workspace.WindowOverlay.prototype.relayout;
@@ -299,7 +281,3 @@ function disable() {
     global.stage.queue_relayout();
     resetState();
 }
-
-function init() {
-    /* do nothing */
-}
