@@ -1,16 +1,13 @@
 /* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
+/* exported init enable disable */
 
 const Clutter = imports.gi.Clutter;
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
-const Shell = imports.gi.Shell;
 const St = imports.gi.St;
 
 const Main = imports.ui.main;
 const PanelMenu = imports.ui.panelMenu;
 const PopupMenu = imports.ui.popupMenu;
-const Panel = imports.ui.panel;
 
 const Gettext = imports.gettext.domain('gnome-shell-extensions');
 const _ = Gettext.gettext;
@@ -18,7 +15,6 @@ const N_ = x => x;
 
 const ExtensionUtils = imports.misc.extensionUtils;
 const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 const PlaceDisplay = Me.imports.placeDisplay;
 
 const PLACE_ICON_SIZE = 16;
@@ -66,14 +62,14 @@ class PlaceMenuItem extends PopupMenu.PopupBaseMenuItem {
         this._icon.gicon = info.icon;
         this._label.text = info.name;
     }
-};
+}
 
 const SECTIONS = [
     'special',
     'devices',
     'bookmarks',
     'network'
-]
+];
 
 let PlacesMenu = GObject.registerClass(
 class PlacesMenu extends PanelMenu.Button {
@@ -92,10 +88,10 @@ class PlacesMenu extends PanelMenu.Button {
 
         this._sections = { };
 
-        for (let i=0; i < SECTIONS.length; i++) {
+        for (let i = 0; i < SECTIONS.length; i++) {
             let id = SECTIONS[i];
             this._sections[id] = new PopupMenu.PopupMenuSection();
-            this.placesManager.connect(id + '-updated', () => {
+            this.placesManager.connect(`${id}-updated`, () => {
                 this._redisplay(id);
             });
 
@@ -127,7 +123,7 @@ class PlacesMenu extends PanelMenu.Button {
 });
 
 function init() {
-    Convenience.initTranslations();
+    ExtensionUtils.initTranslations();
 }
 
 let _indicator;
