@@ -5,14 +5,9 @@ const Gio = imports.gi.Gio;
 const Shell = imports.gi.Shell;
 const Mainloop = imports.mainloop;
 const Signals = imports.signals;
-const St = imports.gi.St;
 
-const DND = imports.ui.dnd;
 const Main = imports.ui.main;
-const Params = imports.misc.params;
-const Search = imports.ui.search;
 const ShellMountOperation = imports.ui.shellMountOperation;
-const Util = imports.misc.util;
 
 const Gettext = imports.gettext.domain('gnome-shell-extensions');
 const _ = Gettext.gettext;
@@ -50,35 +45,37 @@ class PlaceInfo {
         return (_ignored, result) => {
             try {
                 Gio.AppInfo.launch_default_for_uri_finish(result);
-            } catch(e if e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_MOUNTED)) {
-                let source = {
-                    get_icon: () => { return this.icon; }
-                };
-                let op = new ShellMountOperation.ShellMountOperation(source);
-                this.file.mount_enclosing_volume(0, op.mountOp, null, (file, result) => {
-                    try {
-                        op.close();
-                        file.mount_enclosing_volume_finish(result);
-                    } catch(e if e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.FAILED_HANDLED)) {
-                        // e.g. user canceled the password dialog
-                        return;
-                    } catch(e) {
-                        Main.notifyError(_("Failed to mount volume for “%s”").format(this.name), e.message);
-                        return;
-                    }
+            } catch (e) {
+                if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_MOUNTED)) {
+                    let source = {
+                        get_icon: () => { return this.icon; }
+                    };
+                    let op = new ShellMountOperation.ShellMountOperation(source);
+                    this.file.mount_enclosing_volume(0, op.mountOp, null, (file, result) => {
+                        try {
+                            op.close();
+                            file.mount_enclosing_volume_finish(result);
+                        } catch (e) {
+                            if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.FAILED_HANDLED))
+                                // e.g. user canceled the password dialog
+                                return;
+                            Main.notifyError(_("Failed to mount volume for “%s”").format(this.name), e.message);
+                            return;
+                        }
 
-                    if (tryMount) {
-                        let callback = this._createLaunchCallback(launchContext, false);
-                        Gio.AppInfo.launch_default_for_uri_async(file.get_uri(),
-                                                                 launchContext,
-                                                                 null,
-                                                                 callback);
-                    }
-                });
-            } catch(e) {
-                Main.notifyError(_("Failed to launch “%s”").format(this.name), e.message);
+                        if (tryMount) {
+                            let callback = this._createLaunchCallback(launchContext, false);
+                            Gio.AppInfo.launch_default_for_uri_async(file.get_uri(),
+                                                                     launchContext,
+                                                                     null,
+                                                                     callback);
+                        }
+                    });
+                } else {
+                    Main.notifyError(_("Failed to launch “%s”").format(this.name), e.message);
+                }
             }
-        }
+        };
     }
 
     launch(timestamp) {
@@ -97,8 +94,10 @@ class PlaceInfo {
                                            let info = file.query_info_finish(result);
                                            this.icon = info.get_symbolic_icon();
                                            this.emit('changed');
-                                       } catch(e if e instanceof Gio.IOErrorEnum) {
-                                           return;
+                                       } catch (e) {
+                                           if (e instanceof Gio.IOErrorEnum)
+                                               return;
+                                           throw e;
                                        }
                                    });
 
@@ -123,11 +122,13 @@ class PlaceInfo {
         try {
             let info = this.file.query_info('standard::display-name', 0, null);
             return info.get_display_name();
-        } catch(e if e instanceof Gio.IOErrorEnum) {
-            return this.file.get_basename();
+        } catch (e) {
+            if (e instanceof Gio.IOErrorEnum)
+                return this.file.get_basename();
+            throw e;
         }
     }
-};
+}
 Signals.addSignalMethods(PlaceInfo.prototype);
 
 class RootInfo extends PlaceInfo {
@@ -167,7 +168,7 @@ class RootInfo extends PlaceInfo {
         }
         super.destroy();
     }
-};
+}
 
 
 class PlaceDeviceInfo extends PlaceInfo {
@@ -202,7 +203,7 @@ class PlaceDeviceInfo extends PlaceInfo {
     _ejectFinish(mount, result) {
         try {
             mount.eject_with_operation_finish(result);
-        } catch(e) {
+        } catch (e) {
             this._reportFailure(e);
         }
     }
@@ -210,7 +211,7 @@ class PlaceDeviceInfo extends PlaceInfo {
     _unmountFinish(mount, result) {
         try {
             mount.unmount_with_operation_finish(result);
-        } catch(e) {
+        } catch (e) {
             this._reportFailure(e);
         }
     }
@@ -219,7 +220,7 @@ class PlaceDeviceInfo extends PlaceInfo {
         let msg = _("Ejecting drive “%s” failed:").format(this._mount.get_name());
         Main.notifyError(msg, exception.message);
     }
-};
+}
 
 class PlaceVolumeInfo extends PlaceInfo {
     _init(kind, volume) {
@@ -245,7 +246,7 @@ class PlaceVolumeInfo extends PlaceInfo {
     getIcon() {
         return this._volume.get_symbolic_icon();
     }
-};
+}
 
 const DEFAULT_DIRECTORIES = [
     GLib.UserDirectory.DIRECTORY_DOCUMENTS,
@@ -277,7 +278,7 @@ var PlacesManager = class {
         this._connectVolumeMonitorSignals();
         this._updateMounts();
 
-        this._bookmarksFile = this._findBookmarksFile()
+        this._bookmarksFile = this._findBookmarksFile();
         this._bookmarkTimeoutId = 0;
         this._monitor = null;
 
@@ -349,8 +350,10 @@ var PlacesManager = class {
             let file = Gio.File.new_for_path(specialPath), info;
             try {
                 info = new PlaceInfo('special', file);
-            } catch(e if e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_FOUND)) {
-                continue;
+            } catch (e) {
+                if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_FOUND))
+                    continue;
+                throw e;
             }
 
             specials.push(info);
@@ -383,13 +386,13 @@ var PlacesManager = class {
         for (let i = 0; i < drives.length; i++) {
             let volumes = drives[i].get_volumes();
 
-            for(let j = 0; j < volumes.length; j++) {
+            for (let j = 0; j < volumes.length; j++) {
                 let identifier = volumes[j].get_identifier('class');
-                if (identifier && identifier.indexOf('network') >= 0) {
+                if (identifier && identifier.includes('network')) {
                     networkVolumes.push(volumes[j]);
                 } else {
                     let mount = volumes[j].get_mount();
-                    if(mount != null)
+                    if (mount != null)
                         this._addMount('devices', mount);
                 }
             }
@@ -397,27 +400,27 @@ var PlacesManager = class {
 
         /* add all volumes that is not associated with a drive */
         let volumes = this._volumeMonitor.get_volumes();
-        for(let i = 0; i < volumes.length; i++) {
-            if(volumes[i].get_drive() != null)
+        for (let i = 0; i < volumes.length; i++) {
+            if (volumes[i].get_drive() != null)
                 continue;
 
             let identifier = volumes[i].get_identifier('class');
-            if (identifier && identifier.indexOf('network') >= 0) {
+            if (identifier && identifier.includes('network')) {
                 networkVolumes.push(volumes[i]);
             } else {
                 let mount = volumes[i].get_mount();
-                if(mount != null)
+                if (mount != null)
                     this._addMount('devices', mount);
             }
         }
 
         /* add mounts that have no volume (/etc/mtab mounts, ftp, sftp,...) */
         let mounts = this._volumeMonitor.get_mounts();
-        for(let i = 0; i < mounts.length; i++) {
-            if(mounts[i].is_shadowed())
+        for (let i = 0; i < mounts.length; i++) {
+            if (mounts[i].is_shadowed())
                 continue;
 
-            if(mounts[i].get_volume())
+            if (mounts[i].get_volume())
                 continue;
 
             let root = mounts[i].get_default_location();
@@ -514,8 +517,10 @@ var PlacesManager = class {
 
         try {
             devItem = new PlaceDeviceInfo(kind, mount);
-        } catch(e if e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_FOUND)) {
-            return;
+        } catch (e) {
+            if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_FOUND))
+                return;
+            throw e;
         }
 
         this._places[kind].push(devItem);
@@ -526,8 +531,10 @@ var PlacesManager = class {
 
         try {
             volItem = new PlaceVolumeInfo(kind, volume);
-        } catch(e if e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_FOUND)) {
-            return;
+        } catch (e) {
+            if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_FOUND))
+                return;
+            throw e;
         }
 
         this._places[kind].push(volItem);
