@@ -1,3 +1,4 @@
+/* exported enable disable */
 /* Screenshot Window Sizer for Gnome Shell
  *
  * Copyright (c) 2013 Owen Taylor <otaylor@redhat.com>
@@ -18,7 +19,6 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-const Gio = imports.gi.Gio;
 const Meta = imports.gi.Meta;
 const Shell = imports.gi.Shell;
 const St = imports.gi.St;
@@ -27,12 +27,10 @@ const Main = imports.ui.main;
 const Tweener = imports.ui.tweener;
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 const MESSAGE_FADE_TIME = 2;
 
-let text, button;
+let text;
 
 function hideMessage() {
     text.destroy();
@@ -69,7 +67,7 @@ let SIZES = [
     [1600, 900]
 ];
 
-function cycleScreenshotSizes(display, screen, window, binding) {
+function cycleScreenshotSizes(display, window, binding) {
     // Probably this isn't useful with 5 sizes, but you can decrease instead
     // of increase by holding down shift.
     let modifiers = binding.get_modifiers();
@@ -124,8 +122,8 @@ function cycleScreenshotSizes(display, screen, window, binding) {
 
     let newOuterRect = window.get_frame_rect();
     let message = '%d×%d'.format(
-            (newOuterRect.width / scaleFactor),
-            (newOuterRect.height / scaleFactor));
+        (newOuterRect.width / scaleFactor),
+        (newOuterRect.height / scaleFactor));
 
     // The new size might have been constrained by geometry hints (e.g. for
     // a terminal) - in that case, include the actual ratio to the message
@@ -137,17 +135,14 @@ function cycleScreenshotSizes(display, screen, window, binding) {
     flashMessage(message);
 }
 
-function init() {
-}
-
 function enable() {
     Main.wm.addKeybinding('cycle-screenshot-sizes',
-                          Convenience.getSettings(),
+                          ExtensionUtils.getSettings(),
                           Meta.KeyBindingFlags.PER_WINDOW,
                           Shell.ActionMode.NORMAL,
                           cycleScreenshotSizes);
     Main.wm.addKeybinding('cycle-screenshot-sizes-backward',
-                          Convenience.getSettings(),
+                          ExtensionUtils.getSettings(),
                           Meta.KeyBindingFlags.PER_WINDOW |
                           Meta.KeyBindingFlags.IS_REVERSED,
                           Shell.ActionMode.NORMAL,
