@@ -1,45 +1,43 @@
 // -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
 // Load shell theme from ~/.themes/name/gnome-shell
+/* exported init */
 
 const GLib = imports.gi.GLib;
 const Gio = imports.gi.Gio;
-const Lang = imports.lang;
 const Main = imports.ui.main;
 
 const SETTINGS_KEY = 'name';
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
-const ThemeManager = new Lang.Class({
-    Name: 'UserTheme.ThemeManager',
+class ThemeManager {
+    constructor() {
+        this._settings = ExtensionUtils.getSettings();
+    }
 
-    _init: function() {
-        this._settings = Convenience.getSettings();
-    },
-
-    enable: function() {
-        this._changedId = this._settings.connect('changed::'+SETTINGS_KEY, Lang.bind(this, this._changeTheme));
+    enable() {
+        this._changedId = this._settings.connect(`changed::${SETTINGS_KEY}`, this._changeTheme.bind(this));
         this._changeTheme();
-    },
+    }
 
-    disable: function() {
+    disable() {
         if (this._changedId) {
             this._settings.disconnect(this._changedId);
             this._changedId = 0;
         }
 
-        Main._cssStylesheet = null;
+        Main.setThemeStylesheet(null);
         Main.loadTheme();
-    },
+    }
 
-    _changeTheme: function() {
+    _changeTheme() {
         let _stylesheet = null;
         let _themeName = this._settings.get_string(SETTINGS_KEY);
 
         if (_themeName) {
-            let _userCssStylesheet = GLib.get_home_dir() + '/.themes/' + _themeName + '/gnome-shell/gnome-shell.css';
+            let _userCssStylesheet = GLib.build_filenamev([
+                GLib.get_home_dir(), '.themes', _themeName, 'gnome-shell', 'gnome-shell.css'
+            ]);
             let file = Gio.file_new_for_path(_userCssStylesheet);
             if (file.query_exists(null))
                 _stylesheet = _userCssStylesheet;
@@ -47,7 +45,9 @@ const ThemeManager = new Lang.Class({
                 let sysdirs = GLib.get_system_data_dirs();
                 sysdirs.unshift(GLib.get_user_data_dir());
                 for (let i = 0; i < sysdirs.length; i++) {
-                    _userCssStylesheet = sysdirs[i] + '/themes/' + _themeName + '/gnome-shell/gnome-shell.css';
+                    _userCssStylesheet = GLib.build_filenamev([
+                        sysdirs[i], 'themes', _themeName, 'gnome-shell', 'gnome-shell.css'
+                    ]);
                     let file = Gio.file_new_for_path(_userCssStylesheet);
                     if (file.query_exists(null)) {
                         _stylesheet = _userCssStylesheet;
@@ -57,16 +57,14 @@ const ThemeManager = new Lang.Class({
             }
         }
 
-        if (_stylesheet) {
-            global.log('loading user theme: ' + _stylesheet);
-            Main.setThemeStylesheet(_stylesheet);
-        } else {
+        if (_stylesheet)
+            global.log(`loading user theme: ${_stylesheet}`);
+        else
             global.log('loading default theme (Adwaita)');
-            Main._cssStylesheet = null;
-        }
+        Main.setThemeStylesheet(_stylesheet);
         Main.loadTheme();
     }
-});
+}
 
 function init() {
     return new ThemeManager();
