@@ -1,3 +1,4 @@
+/* exported init */
 const Clutter = imports.gi.Clutter;
 const GLib = imports.gi.GLib;
 const Gio = imports.gi.Gio;
@@ -14,7 +15,6 @@ const PopupMenu = imports.ui.popupMenu;
 
 const ExtensionUtils = imports.misc.extensionUtils;
 const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 const Gettext = imports.gettext.domain('gnome-shell-extensions');
 const _ = Gettext.gettext;
@@ -30,12 +30,12 @@ const GroupingMode = {
 
 
 function _minimizeOrActivateWindow(window) {
-        let focusWindow = global.display.focus_window;
-        if (focusWindow == window ||
-            focusWindow && focusWindow.get_transient_for() == window)
-            window.minimize();
-        else
-            window.activate(global.get_current_time());
+    let focusWindow = global.display.focus_window;
+    if (focusWindow == window ||
+        focusWindow && focusWindow.get_transient_for() == window)
+        window.minimize();
+    else
+        window.activate(global.get_current_time());
 }
 
 function _openMenu(menu) {
@@ -50,7 +50,7 @@ function _onMenuStateChanged(menu, isOpen) {
     if (isOpen)
         return;
 
-    let [x, y,] = global.get_pointer();
+    let [x, y] = global.get_pointer();
     let actor = global.stage.get_actor_at_pos(Clutter.PickMode.REACTIVE, x, y);
     if (Me.stateObj.someWindowListContains(actor))
         actor.sync_hover();
@@ -139,7 +139,7 @@ class WindowContextMenu extends PopupMenu.PopupMenu {
         this._metaWindow.disconnect(this._notifyMaximizedHId);
         this._metaWindow.disconnect(this._notifyMaximizedVId);
     }
-};
+}
 
 class WindowTitle {
     constructor(metaWindow) {
@@ -206,7 +206,7 @@ class WindowTitle {
         this._metaWindow.disconnect(this._notifyWmClass);
         this._metaWindow.disconnect(this._notifyAppId);
     }
-};
+}
 
 
 class BaseButton {
@@ -240,10 +240,10 @@ class BaseButton {
         if (this._perMonitor) {
             this._windowEnteredMonitorId =
                 global.display.connect('window-entered-monitor',
-                    this._windowEnteredOrLeftMonitor.bind(this));
+                                       this._windowEnteredOrLeftMonitor.bind(this));
             this._windowLeftMonitorId =
                 global.display.connect('window-left-monitor',
-                    this._windowEnteredOrLeftMonitor.bind(this));
+                                       this._windowEnteredOrLeftMonitor.bind(this));
         }
     }
 
@@ -258,7 +258,7 @@ class BaseButton {
         this._onClicked(this.actor, 1);
     }
 
-    _onClicked(actor, button) {
+    _onClicked(_actor, _button) {
         throw new Error('Not implemented');
     }
 
@@ -266,7 +266,7 @@ class BaseButton {
         return true;
     }
 
-    _onPopupMenu(actor) {
+    _onPopupMenu(_actor) {
         if (!this._canOpenPopupMenu() || this._contextMenu.isOpen)
             return;
         _openMenu(this._contextMenu);
@@ -283,7 +283,7 @@ class BaseButton {
             this.actor.remove_style_class_name('focused');
     }
 
-    _windowEnteredOrLeftMonitor(metaDisplay, monitorIndex, metaWindow) {
+    _windowEnteredOrLeftMonitor(_metaDisplay, _monitorIndex, _metaWindow) {
         throw new Error('Not implemented');
     }
 
@@ -323,7 +323,7 @@ class BaseButton {
             global.display.disconnect(this._windowLeftMonitorId);
         this._windowLeftMonitorId = 0;
     }
-};
+}
 
 
 class WindowButton extends BaseButton {
@@ -397,7 +397,7 @@ class WindowButton extends BaseButton {
         global.display.disconnect(this._notifyFocusId);
         this._contextMenu.destroy();
     }
-};
+}
 
 
 class AppContextMenu extends PopupMenu.PopupMenu {
@@ -458,7 +458,7 @@ class AppContextMenu extends PopupMenu.PopupMenu {
 
         super.open(animate);
     }
-};
+}
 
 class AppButton extends BaseButton {
     constructor(app, perMonitor, monitorIndex) {
@@ -639,7 +639,7 @@ class AppButton extends BaseButton {
         this.app.disconnect(this._windowsChangedId);
         this._menu.destroy();
     }
-};
+}
 
 
 let WorkspaceIndicator = GObject.registerClass(
@@ -714,12 +714,12 @@ class WorkspaceIndicator extends PanelMenu.Button {
         this.workspacesItems = [];
         this._currentWorkspace = workspaceManager.get_active_workspace().index();
 
-        for(let i = 0; i < workspaceManager.n_workspaces; i++) {
+        for (let i = 0; i < workspaceManager.n_workspaces; i++) {
             let name = Meta.prefs_get_workspace_name(i);
             let item = new PopupMenu.PopupMenuItem(name);
             item.workspaceId = i;
 
-            item.connect('activate', (item, event) => {
+            item.connect('activate', (item, _event) => {
                 this._activate(item.workspaceId);
             });
 
@@ -736,7 +736,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
     _activate(index) {
         let workspaceManager = global.workspace_manager;
 
-        if(index >= 0 && index < workspaceManager.n_workspaces) {
+        if (index >= 0 && index < workspaceManager.n_workspaces) {
             let metaWorkspace = workspaceManager.get_workspace_by_index(index);
             metaWorkspace.activate(global.get_current_time());
         }
@@ -772,7 +772,7 @@ class WindowList {
                                      style_class: 'bottom-panel solid',
                                      reactive: true,
                                      track_hover: true,
-                                     layout_manager: new Clutter.BinLayout()});
+                                     layout_manager: new Clutter.BinLayout() });
         this.actor.connect('destroy', this._onDestroy.bind(this));
 
         let box = new St.BoxLayout({ x_expand: true, y_expand: true });
@@ -882,7 +882,7 @@ class WindowList {
         this._dndTimeoutId = 0;
         this._dndWindow = null;
 
-        this._settings = Convenience.getSettings();
+        this._settings = ExtensionUtils.getSettings();
         this._groupingModeChangedId =
             this._settings.connect('changed::grouping-mode',
                                    this._groupingModeChanged.bind(this));
@@ -904,7 +904,7 @@ class WindowList {
             .filter(c => c.visible)
             .map(a => a._delegate);
         let active = children.findIndex(c => c.active);
-        let newActive = Math.max(0, Math.min(active + diff, children.length-1));
+        let newActive = Math.max(0, Math.min(active + diff, children.length - 1));
         children[newActive].activate();
     }
 
@@ -1188,7 +1188,7 @@ class WindowList {
         for (let i = 0; i < windows.length; i++)
             windows[i].metaWindow.set_icon_geometry(null);
     }
-};
+}
 
 class Extension {
     constructor() {
@@ -1199,7 +1199,7 @@ class Extension {
     enable() {
         this._windowLists = [];
 
-        this._settings = Convenience.getSettings();
+        this._settings = ExtensionUtils.getSettings();
         this._showOnAllMonitorsChangedId =
             this._settings.connect('changed::show-on-all-monitors',
                                    this._buildWindowLists.bind(this));
@@ -1243,7 +1243,7 @@ class Extension {
     someWindowListContains(actor) {
         return this._windowLists.some(list => list.actor.contains(actor));
     }
-};
+}
 
 function init() {
     return new Extension();
