@@ -1,4 +1,5 @@
 // -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
+/* exported init buildPrefsWidget */
 
 const Gio = imports.gi.Gio;
 const GObject = imports.gi.GObject;
@@ -8,12 +9,10 @@ const Gettext = imports.gettext.domain('gnome-shell-extensions');
 const _ = Gettext.gettext;
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 
 function init() {
-    Convenience.initTranslations();
+    ExtensionUtils.initTranslations();
 }
 
 const WindowListPrefsWidget = GObject.registerClass(
@@ -25,7 +24,7 @@ class WindowListPrefsWidget extends Gtk.Grid {
         this.row_spacing = 6;
         this.orientation = Gtk.Orientation.VERTICAL;
 
-        let groupingLabel = '<b>' + _("Window Grouping") + '</b>';
+        let groupingLabel = '<b>%s</b>'.format(_("Window Grouping"));
         this.add(new Gtk.Label({ label: groupingLabel, use_markup: true,
                                  halign: Gtk.Align.START }));
 
@@ -37,7 +36,7 @@ class WindowListPrefsWidget extends Gtk.Grid {
                                   column_spacing: 6 });
         align.add(grid);
 
-        this._settings = Convenience.getSettings();
+        this._settings = ExtensionUtils.getSettings();
         let currentMode = this._settings.get_string('grouping-mode');
         let range = this._settings.get_range('grouping-mode');
         let modes = range.deep_unpack()[1].deep_unpack();
@@ -53,8 +52,8 @@ class WindowListPrefsWidget extends Gtk.Grid {
             let mode = modes[i];
             let label = modeLabels[mode];
             if (!label) {
-               log('Unhandled option "%s" for grouping-mode'.format(mode));
-               continue;
+                log('Unhandled option "%s" for grouping-mode'.format(mode));
+                continue;
             }
 
             radio = new Gtk.RadioButton({ active: currentMode == mode,
