@@ -1,6 +1,6 @@
 /* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
+/* exported enable disable */
 const Clutter = imports.gi.Clutter;
-const Mainloop = imports.mainloop;
 const St = imports.gi.St;
 
 const Main = imports.ui.main;
@@ -15,18 +15,18 @@ function injectToFunction(parent, name, func) {
         if (ret === undefined)
             ret = func.apply(this, arguments);
         return ret;
-    }
+    };
     return origin;
 }
 
 let winInjections, workspaceInjections, workViewInjections, createdActors, connectedSignals;
 
 function resetState() {
-    winInjections = { };
-    workspaceInjections = { };
-    workViewInjections = { };
-    createdActors = [ ];
-    connectedSignals = [ ];
+    winInjections = {};
+    workspaceInjections = {};
+    workViewInjections = {};
+    createdActors = [];
+    connectedSignals = [];
 }
 
 function enable() {
@@ -36,13 +36,13 @@ function enable() {
         this._text.raise_top();
         this._text.show();
         this._text.text = (this._windowClone.slotId + 1).toString();
-    }
+    };
     winInjections['showTooltip'] = undefined;
 
     Workspace.WindowOverlay.prototype.hideTooltip = function() {
         if (this._text && this._text.visible)
             this._text.hide();
-    }
+    };
     winInjections['hideTooltip'] = undefined;
 
     Workspace.Workspace.prototype.showTooltip = function() {
@@ -65,7 +65,7 @@ function enable() {
         this._tip.y = area.y;
         this._tip.show();
         this._tip.raise_top();
-    }
+    };
     workspaceInjections['showTooltip'] = undefined;
 
     Workspace.Workspace.prototype.hideTooltip = function() {
@@ -74,7 +74,7 @@ function enable() {
         if (!this._tip.get_parent())
             return;
         this._tip.hide();
-    }
+    };
     workspaceInjections['hideTooltip'] = undefined;
 
     Workspace.Workspace.prototype.getWindowWithTooltip = function(id) {
@@ -83,7 +83,7 @@ function enable() {
                 return this._windows[i].metaWindow;
         }
         return null;
-    }
+    };
     workspaceInjections['getWindowWithTooltip'] = undefined;
 
     Workspace.Workspace.prototype.showWindowsTooltips = function() {
@@ -91,7 +91,7 @@ function enable() {
             if (this._windowOverlays[i] != null)
                 this._windowOverlays[i].showTooltip();
         }
-    }
+    };
     workspaceInjections['showWindowsTooltips'] = undefined;
 
     Workspace.Workspace.prototype.hideWindowsTooltips = function() {
@@ -99,7 +99,7 @@ function enable() {
             if (this._windowOverlays[i] != null)
                 this._windowOverlays[i].hideTooltip();
         }
-    }
+    };
     workspaceInjections['hideWindowsTooltips'] = undefined;
 
     WorkspacesView.WorkspacesView.prototype._hideTooltips = function() {
@@ -108,7 +108,7 @@ function enable() {
         this._pickWindow = false;
         for (let i = 0; i < this._workspaces.length; i++)
             this._workspaces[i].hideWindowsTooltips();
-    }
+    };
     workViewInjections['_hideTooltips'] = undefined;
 
     WorkspacesView.WorkspacesView.prototype._hideWorkspacesTooltips = function() {
@@ -116,7 +116,7 @@ function enable() {
         this._pickWorkspace = false;
         for (let i = 0; i < this._workspaces.length; i++)
             this._workspaces[i].hideTooltip();
-    }
+    };
     workViewInjections['_hideWorkspacesTooltips'] = undefined;
 
     WorkspacesView.WorkspacesView.prototype._onKeyRelease = function(s, o) {
@@ -128,11 +128,11 @@ function enable() {
             (o.get_key_symbol() == Clutter.KEY_Control_L ||
              o.get_key_symbol() == Clutter.KEY_Control_R))
             this._hideWorkspacesTooltips();
-    }
+    };
     workViewInjections['_onKeyRelease'] = undefined;
 
     WorkspacesView.WorkspacesView.prototype._onKeyPress = function(s, o) {
-        if(Main.overview.viewSelector._activePage != Main.overview.viewSelector._workspacesPage)
+        if (Main.overview.viewSelector._activePage != Main.overview.viewSelector._workspacesPage)
             return false;
 
         let workspaceManager = global.workspace_manager;
@@ -209,7 +209,7 @@ function enable() {
             return true;
         }
         return false;
-    }
+    };
     workViewInjections['_onKeyPress'] = undefined;
 
     winInjections['_init'] = injectToFunction(Workspace.WindowOverlay.prototype, '_init', function(windowClone, parentActor) {
@@ -219,8 +219,8 @@ function enable() {
         parentActor.add_actor(this._text);
     });
 
-    winInjections['relayout'] = injectToFunction(Workspace.WindowOverlay.prototype, 'relayout', function(animate) {
-        let [cloneX, cloneY, cloneWidth, cloneHeight] = this._windowClone.slot;
+    winInjections['relayout'] = injectToFunction(Workspace.WindowOverlay.prototype, 'relayout', function(_animate) {
+        let [cloneX, cloneY, cloneWidth_, cloneHeight_] = this._windowClone.slot;
 
         let textX = cloneX - 2;
         let textY = cloneY - 2;
@@ -242,7 +242,7 @@ function enable() {
             this._tip = null;
     });
 
-    workViewInjections['_init'] = injectToFunction(WorkspacesView.WorkspacesView.prototype, '_init', function(width, height, x, y, workspaces) {
+    workViewInjections['_init'] = injectToFunction(WorkspacesView.WorkspacesView.prototype, '_init', function(_width, _height, _x, _y, _workspaces) {
         this._pickWorkspace = false;
         this._pickWindow = false;
         this._keyPressEventId =
@@ -256,7 +256,7 @@ function enable() {
     workViewInjections['_onDestroy'] = injectToFunction(WorkspacesView.WorkspacesView.prototype, '_onDestroy', function() {
         global.stage.disconnect(this._keyPressEventId);
         global.stage.disconnect(this._keyReleaseEventId);
-        connectedSignals = [ ];
+        connectedSignals = [];
     });
 }
 
@@ -285,7 +285,3 @@ function disable() {
 
     resetState();
 }
-
-function init() {
-    /* do nothing */
-}
