@@ -1,14 +1,13 @@
 // -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
+/* exported init enable disable */
 
 const Gio = imports.gi.Gio;
 const GObject = imports.gi.GObject;
 const Meta = imports.gi.Meta;
 const Clutter = imports.gi.Clutter;
 const St = imports.gi.St;
-const Mainloop = imports.mainloop;
 const PanelMenu = imports.ui.panelMenu;
 const PopupMenu = imports.ui.popupMenu;
-const Panel = imports.ui.panel;
 
 const Gettext = imports.gettext.domain('gnome-shell-extensions');
 const _ = Gettext.gettext;
@@ -16,8 +15,6 @@ const _ = Gettext.gettext;
 const Main = imports.ui.main;
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 const WORKSPACE_SCHEMA = 'org.gnome.desktop.wm.preferences';
 const WORKSPACE_KEY = 'workspace-names';
@@ -55,7 +52,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
 
         this._settings = new Gio.Settings({ schema_id: WORKSPACE_SCHEMA });
         this._settingsChangedId =
-            this._settings.connect('changed::' + WORKSPACE_KEY,
+            this._settings.connect(`changed::${WORKSPACE_KEY}`,
                                    this._createWorkspacesSection.bind(this));
     }
 
@@ -80,7 +77,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
     }
 
     _labelText(workspaceIndex) {
-        if(workspaceIndex == undefined) {
+        if (workspaceIndex == undefined) {
             workspaceIndex = this._currentWorkspace;
             return (workspaceIndex + 1).toString();
         }
@@ -95,13 +92,12 @@ class WorkspaceIndicator extends PanelMenu.Button {
         this._currentWorkspace = workspaceManager.get_active_workspace().index();
 
         let i = 0;
-        for(; i < workspaceManager.n_workspaces; i++) {
+        for (; i < workspaceManager.n_workspaces; i++) {
             this.workspacesItems[i] = new PopupMenu.PopupMenuItem(this._labelText(i));
             this._workspaceSection.addMenuItem(this.workspacesItems[i]);
             this.workspacesItems[i].workspaceId = i;
             this.workspacesItems[i].label_actor = this.statusLabel;
-            let self = this;
-            this.workspacesItems[i].connect('activate', (actor, event) => {
+            this.workspacesItems[i].connect('activate', (actor, _event) => {
                 this._activate(actor.workspaceId);
             });
 
@@ -115,7 +111,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
     _activate(index) {
         let workspaceManager = global.workspace_manager;
 
-        if(index >= 0 && index <  workspaceManager.n_workspaces) {
+        if (index >= 0 && index <  workspaceManager.n_workspaces) {
             let metaWorkspace = workspaceManager.get_workspace_by_index(index);
             metaWorkspace.activate(global.get_current_time());
         }
@@ -137,8 +133,8 @@ class WorkspaceIndicator extends PanelMenu.Button {
     }
 });
 
-function init(meta) {
-    Convenience.initTranslations();
+function init() {
+    ExtensionUtils.initTranslations();
 }
 
 let _indicator;
