@@ -1,7 +1,7 @@
 // -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
+/* exported init buildPrefsWidget */
 
 const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 
@@ -10,8 +10,6 @@ const _ = Gettext.gettext;
 const N_ = e => e;
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 const WORKSPACE_SCHEMA = 'org.gnome.desktop.wm.preferences';
 const WORKSPACE_KEY = 'workspace-names';
@@ -115,7 +113,7 @@ class WorkspaceNameModel extends Gtk.ListStore {
         names.splice(index, 1);
 
         // compact the array
-        for (let i = names.length -1; i >= 0 && !names[i]; i++)
+        for (let i = names.length - 1; i >= 0 && !names[i]; i++)
             names.pop();
 
         this._settings.set_strv(WORKSPACE_KEY, names);
@@ -131,7 +129,7 @@ class WorkspaceSettingsWidget extends Gtk.Grid {
         this.margin = 12;
         this.orientation = Gtk.Orientation.VERTICAL;
 
-        this.add(new Gtk.Label({ label: '<b>' + _("Workspace Names") + '</b>',
+        this.add(new Gtk.Label({ label: '<b>%s</b>'.format(_("Workspace Names")),
                                  use_markup: true, margin_bottom: 6,
                                  hexpand: true, halign: Gtk.Align.START }));
 
@@ -144,8 +142,7 @@ class WorkspaceSettingsWidget extends Gtk.Grid {
                                             headers_visible: false,
                                             reorderable: true,
                                             hexpand: true,
-                                            vexpand: true
-                                          });
+                                            vexpand: true });
 
         let column = new Gtk.TreeViewColumn({ title: _("Name") });
         let renderer = new Gtk.CellRendererText({ editable: true });
@@ -176,11 +173,11 @@ class WorkspaceSettingsWidget extends Gtk.Grid {
         this.add(toolbar);
     }
 
-    _cellEdited(renderer, path, new_text) {
+    _cellEdited(renderer, path, newText) {
         let [ok, iter] = this._store.get_iter_from_string(path);
 
         if (ok)
-            this._store.set(iter, [this._store.Columns.LABEL], [new_text]);
+            this._store.set(iter, [this._store.Columns.LABEL], [newText]);
     }
 
     _newClicked() {
@@ -192,7 +189,7 @@ class WorkspaceSettingsWidget extends Gtk.Grid {
     }
 
     _delClicked() {
-        let [any, model, iter] = this._treeView.get_selection().get_selected();
+        let [any, model_, iter] = this._treeView.get_selection().get_selected();
 
         if (any)
             this._store.remove(iter);
@@ -200,7 +197,7 @@ class WorkspaceSettingsWidget extends Gtk.Grid {
 });
 
 function init() {
-    Convenience.initTranslations();
+    ExtensionUtils.initTranslations();
 }
 
 function buildPrefsWidget() {
